/* NetworkManager -- Network link manager
 *
 * Patryk Zawadzki <patrys@pld-linux.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * (C) Copyright 2004 RedHat, Inc.
 * (C) Copyright 2004 Narayan Newton
 * (C) Copyright 2005 wrobell <wrobell@pld-linux.org>
 * (C) Copyright 2007, 2012 Marcin Banasiak <megabajt@pld-linux.org>
 * (C) Copyright 2005-2008 Patryk Zawadzki <patrys@pld-linux.org>
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "NetworkManagerGeneric.h"
#include "NetworkManagerUtils.h"

/*
 * nm_backend_enable_loopback
 *
 * Bring up the loopback interface
 *
 */
void nm_backend_enable_loopback (void)
{
	nm_generic_enable_loopback ();
}

/*
 * nm_backend_update_dns
 *
 * Invalidate the nscd host cache, if it exists, since
 * we changed resolv.conf.
 *
 */
void nm_backend_update_dns (void)
{
	if (g_file_test ("/usr/sbin/nscd", G_FILE_TEST_EXISTS | G_FILE_TEST_IS_EXECUTABLE | G_FILE_TEST_IS_REGULAR)) {
		nm_spawn_process ("/usr/sbin/nscd -i hosts");
	}
}

/*
 * nm_backend_ipv6_use_tempaddr
 *
 * Get net.ipv6.conf.default.use_tempaddr from /etc/sysctl.conf or
 * /lib/sysctl.d/sysctl.conf
 *
 */
int nm_backend_ipv6_use_tempaddr (void)
{
	return nm_generic_ipv6_use_tempaddr ();
}
